
#ifndef _C10_kl485_
#define _C10_kl485_

#ifdef __cplusplus
extern "C" {
#endif
RTOSHF (EIF_REFERENCE, 9397)


extern EIF_REFERENCE F1301_9397(EIF_REFERENCE);
extern void EIF_Minit485(void);

#ifdef __cplusplus
}
#endif

#endif
